/**
@file      manualView.js
@brief     Philips Hue Plugin
@copyright (c) 2019, Corsair Memory, Inc.
@license   This source code is licensed under the MIT-style license found in the LICENSE file.
*/
loadManualView()
// Load the manual view
function loadManualView() {
    // Set cursor to input field
    document.getElementById('ip').focus();

    // Add event listener
    document.getElementById('check').addEventListener('click', check);
    // document.addEventListener('enterPressed', check);

    // Print error message
    function printError(error) {
        document.getElementById('ip-validation').innerHTML = `<div class="error">${error}</div>`;
    }

    // Check ip address
    function check() {
        let ip = document.getElementById('ip').value.trim();

        // check if input is empty
        if (!ip) {
            printError('Validate input');
            return;
        }

        // check if ip is invalid
        let ipV4Regex = '^(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}$';
        if (!(new RegExp(ipV4Regex)).test(ip)) {
            printError('Validate input');
            return;
        }

        baseURL = `http://${ip}`

        getStatemachine()
        function getStatemachine() {
            request('/mwapi/statemachine').then(data => {

                // pair(baseURL);
                getDirectorDeviceInfo()

            }).catch(err => {
                printError('Magewell Director is not reachable. Please check the ip address.');
            });
        }
    }
    // Open pairing view
    function getDirectorDeviceInfo() {
        request('/mwapi/device/get-device-info').then(data => {
            if (data.status === 0) {

                const appVersion = data.appVersion
                const versionArr = appVersion.split('.')
                const version = versionArr[0]
                // 1319 obsbot
                if (data.productId == 1319) {
                    printError('Magewell Director is not reachable. Please check the ip address.');
                    return
                }
                if (Number(version) < 3) {
                    printError('The current device version is too low and cannot use Magewell Director plugin. Please upgrade to V3.0 or higher.');
                } else {
                    const channel = new BroadcastChannel('myChannel');
                    channel.postMessage(baseURL);
                    pair(baseURL);
                }
            }
            
        }).catch(err => {
            printError('Magewell Director is not reachable. Please check the ip address.');
        });
    }

    // Open pairing view
    function pair() {
        unloadManualView();
        close()
    }

    // Close the window
    function close() {
        window.close();
    }

    // Unload view
    function unloadManualView() {
        // Remove event listener
        document.removeEventListener('enterPressed', check);
    }
}
