const ptzAction = new Action('com.magewell.magewell-director.ptz');

// ptz 临时数据存储的地方.
let ptzTempDataObj = {};
ptzAction.onKeyUp((e) => {
    const settings = e.payload.settings;
    if (settings.hasOwnProperty("ptzInfo")) {
        const { ptzInfo } = settings;
        const name = ptzInfo.selFunctionItem.name;
        switch (name) {
            case "ptzZoomIn":
            case "ptzZoomOut":
                console.log('ptz onKeyup api', "/V1.0/ptz/zoomStop");
                request("/V1.0/ptz/zoomStop").then(data => {}).catch(err => {
                    $SD.showAlert(e.context)
                });
                break;
            case "ptzMoveUp":
            case "ptzMoveUpLeft":
            case "ptzMoveLeft":
            case "ptzMoveDown":
            case "ptzMoveDownLeft":
            case "ptzMoveDownRight":
            case "ptzMoveRight":
            case "ptzMoveUpRight":
                console.log('ptz onKeyup api', "/V1.0/ptz/moveStop");
                request("/V1.0/ptz/moveStop").then(data => {}).catch(err => {
                    $SD.showAlert(e.context)
                });
                break;
            case "ptzFocusFar":
            case "ptzFocusNear":
                if(ptzTempDataObj[e.context]) {
                    if(ptzTempDataObj[e.context].timer) {
                        clearInterval(ptzTempDataObj[e.context].timer);
                    }

                    ptzTempDataObj[e.context].ptzInfo.clickTime = Date.now();
                    $SD.setSettings(e.context, {
                        baseURL: baseURL,
                        networkIsError: settings?.networkIsError??null,
                        ptzInfo: ptzTempDataObj[e.context].ptzInfo,
                    });

                    delete ptzTempDataObj[e.context];
                }
                break;
        }
    }
})

ptzAction.onKeyDown((e) => {
    const settings = e.payload.settings
    if (settings.hasOwnProperty("ptzInfo")) {
        const { ptzInfo } = settings;
        const info = ptzInfo;
        const { name, paramsKey } = info.selFunctionItem;
        if(info.selFunctionItem.paramsKey) {
            if(name === 'ptzFocusFar' || name === "ptzFocusNear") {
                ptzTempDataObj[e.context] = {
                    context: e.context,
                    ptzInfo: info,
                    baseURL: baseURL,
                    timer: null,
                    e: e,
                }

                focusMethod(e.context, settings);
            }

            // 开始判断是什么操作并开始设置参数
            switch (name) {
                case "ptzSelectDevice":
                    paramsKey['id'] = info.selPtzId;
                    break;
                case "ptzCallPreset":
                case "ptzStorePreset":
                    paramsKey['position'] = info.selPreset;
                    break;
                case "ptzZoomIn":
                case "ptzZoomOut":
                    paramsKey['speed'] = parseInt(info.selZoomSpeed)/ 10;
                    break;
                case "ptzMoveUp":
                case "ptzMoveUpLeft":
                case "ptzMoveLeft":
                case "ptzMoveDown":
                case "ptzMoveDownLeft":
                case "ptzMoveDownRight":
                case "ptzMoveRight":
                case "ptzMoveUpRight":
                    paramsKey['speed'] = parseInt(info.selSpeed)/ 10;
                    break;
                case "ptzSetAiHumanTrackingMode":
                    paramsKey['mode'] = info.selTrackingMode;
                    break;
                case "ptzSetAiHumanTrackingSpeed":
                    paramsKey['speed'] = info.selTrackingSpeed;
                    break;
                case "ptzSetAiHumanTrackingType":
                    paramsKey['type'] = info.selTrackingType;
                    break;
                case "ptzFocusFar":
                case "ptzFocusNear":
                    return ;
            }

            info.selFunctionItem.paramsKey = paramsKey;
        }

        ptzActionRequestApi(info, e);
    }
});

function focusMethod(context, settings){
    if(!ptzTempDataObj[context]) return ;

    let { ptzInfo, e } = ptzTempDataObj[context];
    const info = ptzInfo;
    const { name, paramsKey } = info.selFunctionItem;
    let tempValue = 0;
    if(info.clickTime && info.clickTime < (Date.now() - 2000)) {
        if(name === 'ptzFocusFar') {
            info.selFarSpeed = "0";
            tempValue = parseInt(info.selFarSpeed);
        } else {
            info.selNearSpeed = "10";
            tempValue =  parseInt(info.selNearSpeed);
        }
    } else {
        if(name === 'ptzFocusFar') {
            tempValue = parseInt(info.selFarSpeed) + 1;
        } else {
            tempValue = parseInt(info.selNearSpeed) - 1;
        }
    }

    if(tempValue < 0) {
        tempValue = 0 + '';
    } else if(tempValue > 10) {
        tempValue = 10+"";
    }

    tempValue = tempValue+"";
    if(name === 'ptzFocusFar') {
        info.selFarSpeed = tempValue;
        paramsKey['focusValue'] = parseInt(info.selFarSpeed)/ 10;
    } else {
        info.selNearSpeed = tempValue;
        paramsKey['focusValue'] = parseInt(info.selNearSpeed)/ 10;
    }

    info.title = tempValue;
    info.clickTime = Date.now();
    info.selFunctionItem.paramsKey = paramsKey;
    ptzTempDataObj[context].ptzInfo = info;

    $SD.setTitle(e.context, tempValue);
    
    $SD.setSettings(e.context, {
        baseURL: baseURL,
        networkIsError: settings?.networkIsError??null,
        ptzInfo: info,
    });

    if(!ptzTempDataObj[e.context].timer) {
        ptzTempDataObj[e.context].timer = setInterval(function(){
            focusMethod(e.context, settings)
        }, 500);
    }

    ptzActionRequestApi(info, e);
}

function ptzSetImageAndTitle(e) {
    let ptzInfo = e.payload.settings.ptzInfo
    console.log('ptzInfo ', ptzInfo);
    let title = ''
    ptzInfo = ptzInfo || {}
    if (ptzInfo.hasOwnProperty('title') && ptzInfo.title) {
        title = String(ptzInfo.title)
    }

    if ($SD.localization.ptz[title]) {
        $SD.setTitle(e.context, $SD.localization.ptz[title])
    } else {
        $SD.setTitle(e.context, title)
    }

    const img = 'image/ptz/' + ptzInfo.iconPath
    $SD.setImage(e.context, img);
}

ptzAction.onWillAppear((e) => {
    const setting = e.payload.settings
    console.log('ptzAction onWillAppear', e)
    if (setting.hasOwnProperty('baseURL') && !baseURL) {
        baseURL = setting.baseURL
        $SD.sendToPropertyInspector(e.context, e.action, setting)
    }

    ptzSetImageAndTitle(e)
})

ptzAction.onDidReceiveSettings((e) => {
    console.log('ptzAction onDidReceiveSettings', e)
    ptzSetImageAndTitle(e);
})

function ptzActionRequestApi (dataInfo, action) {
    let path = dataInfo.selFunction;
    const selFunctionItem = dataInfo.selFunctionItem;
    if (selFunctionItem.hasOwnProperty('paramsKey')) {
        const paramsKey = selFunctionItem.paramsKey;
        let num = 1;
        if(path === "ptzFocusFar" || path === "ptzFocusNear") {
            path = "/V1.0/ptz/focusExact";
        }

        path = path + '?'
        for (let key in paramsKey) {
            path = num === 1 ? path + key + '=' + paramsKey[key] : path + '&' + key + '=' + paramsKey[key];
            num++
        }
    }

    console.log('ptzAction api', path);
    request(path).then(data => {}).catch(err => {
        $SD.showAlert(action.context)
    });
}
